@@ -30,10 +30,14 @@ import hubzero.data.db
 import re
 import os
 
+
+def getDefaultSite():
+	return hubzero.config.hubzerositeconfig.getHubzeroConfigOption("DEFAULT", "site")
+	
+
 def getWebConfigOption(optionName):
 	
-	# get the locaiton of the web config file
-	defaultSite = hubzero.config.hubzerositeconfig.getHubzeroConfigOption("DEFAULT", "site")
+	defaultSite = getDefaultSite()
 	wwwDocRoot = hubzero.config.hubzerositeconfig.getHubzeroConfigOption(defaultSite, "DocumentRoot")	
 	
 	# read config values from file
